@@ -8,6 +8,8 @@ import sys
 from six.moves import urllib
 import six
 
+from shopify.collection import PaginatedCollection
+from pyactiveresource.collection import Collection
 
 # Store the response from the last request in the connection object
 class ShopifyConnection(pyactiveresource.connection.Connection):
@@ -41,6 +43,8 @@ class ShopifyResourceMeta(ResourceMeta):
             local.timeout = cls.timeout
             local.headers = cls.headers
             local.format = cls.format
+            local.version = cls.version
+            local.url = cls.url
             if cls.site is None:
                 raise ValueError("No shopify session is active")
             local.connection = ShopifyConnection(
@@ -75,6 +79,11 @@ class ShopifyResourceMeta(ResourceMeta):
         ShopifyResource._site = cls._threadlocal.site = value
         if value is not None:
             parts = urllib.parse.urlparse(value)
+            host = parts.hostname
+            if parts.port:
+                host += ":" + str(parts.port)
+            new_site = urllib.parse.urlunparse((parts.scheme, host, parts.path, '', '', ''))
+            ShopifyResource._site = cls._threadlocal.site = new_site
             if parts.username:
                 cls.user = urllib.parse.unquote(parts.username)
             if parts.password:
@@ -114,12 +123,57 @@ class ShopifyResourceMeta(ResourceMeta):
     format = property(get_format, set_format, None,
                       'Encoding used for request and responses')
 
+    def get_prefix_source(cls):
+        """Return the prefix source, by default derived from site."""
+        try:
+            return cls.override_prefix()
+        except AttributeError:
+            if hasattr(cls, '_prefix_source'):
+                return cls.site + cls._prefix_source
+            else:
+                return cls.site
+
+    def set_prefix_source(cls, value):
+        """Set the prefix source, which will be rendered into the prefix."""
+        cls._prefix_source = value
+
+    prefix_source = property(get_prefix_source, set_prefix_source, None,
+                             'prefix for lookups for this type of object.')
+    def get_version(cls):
+        return getattr(cls._threadlocal, 'version', ShopifyResource._version)
+
+    def set_version(cls, value):
+        ShopifyResource._version = cls._threadlocal.version = value
+
+    version = property(get_version, set_version, None,
+                      'Shopify Api Version')
+
+    def get_version(cls):
+        return getattr(cls._threadlocal, 'version', ShopifyResource._version)
+
+    def set_version(cls, value):
+        ShopifyResource._version = cls._threadlocal.version = value
+
+    version = property(get_version, set_version, None,
+                      'Shopify Api Version')
+
+    def get_url(cls):
+        return getattr(cls._threadlocal, 'url', ShopifyResource._url)
+
+    def set_url(cls, value):
+        ShopifyResource._url = cls._threadlocal.url = value
+
+    url = property(get_url, set_url, None,
+                      'Base URL including protocol and shopify domain')
+
 
 @six.add_metaclass(ShopifyResourceMeta)
 class ShopifyResource(ActiveResource, mixins.Countable):
     _format = formats.JSONFormat
     _threadlocal = threading.local()
     _headers = {'User-Agent': 'ShopifyPythonAPI/%s Python/%s' % (shopify.VERSION, sys.version.split(' ', 1)[0])}
+    _version = None
+    _url = None
 
     def __init__(self, attributes=None, prefix_options=None):
         if attributes is not None and prefix_options is None:
@@ -136,13 +190,25 @@ class ShopifyResource(ActiveResource, mixins.Countable):
     @classmethod
     def activate_session(cls, session):
         cls.site = session.site
+        cls.url = session.url
         cls.user = None
         cls.password = None
+        cls.version = session.api_version.name
         cls.headers['X-Shopify-Access-Token'] = session.token
 
     @classmethod
     def clear_session(cls):
         cls.site = None
+        cls.url = None
         cls.user = None
         cls.password = None
+        cls.version = None
         cls.headers.pop('X-Shopify-Access-Token', None)
+
+    @classmethod
+    def find(cls, id_=None, from_=None, **kwargs):
+        """Checks the resulting collection for pagination metadata."""
+        collection = super(ShopifyResource, cls).find(id_=id_, from_=from_, **kwargs)
+        if isinstance(collection, Collection) and "headers" in collection.metadata:
+            return PaginatedCollection(collection, metadata={"resource_class": cls}, **kwargs)
+        return collection
