@@ -1,5 +1,6 @@
 from ..base import ShopifyResource
 
 class OrderRisk(ShopifyResource):
-  _prefix_source = "/admin/orders/$order_id/"
+  _prefix_source = "/orders/$order_id/"
+  _singular = "risk"
   _plural = "risks"
